|PyPI|

ps_crud
=======

`ps_crud` is extension for `pyramid_sacrud
<https://github.com/sacrud/pyramid_sacrud/>`_ which provides a templates for
CRUD.

Support and Development
=======================

To report bugs, use the `issue tracker
<https://github.com/sacrud/ps_crud/issues>`_

We welcome any contribution: suggestions, ideas, commits with new futures,
bug fixes, refactoring, docs, tests, translations etc

If you have question, contact me sacrud@uralbash.ru or IRC channel #sacrud

License
=======

The project is licensed under the MIT license.

.. |PyPI| image:: http://img.shields.io/pypi/dm/ps_crud.svg
   :target: https://pypi.python.org/pypi/ps_crud/
